@@ -106,7 +106,13 @@ class kafkaMedia:
         if not isinstance(key, bytes):
             key = key.encode("utf-8")
 
-        self.producer.send(self.topic, key=key, value=value)
+        try:
+            self.producer.send(self.topic, key=key, value=value)
+        except Exception as e:
+            print(self.producer)
+            print("key", key)
+            print("value", value)
+            print(e)
         # producer.flush()
 
     def send_kafka(self, task_id=None, value=None):
